@@ -26,11 +26,11 @@ class EventManager:
         else:
             self.http_client = http_client
 
+        self.queue = list()
         self.thread = threading.Thread(target=self.run, daemon=True)
         self.thread.start()
 
         self.options = options
-        self.queue = list()
         self.send_enabled = False
         self.attempt = 0
         self.coefficients = [1, 1, 2, 3, 5, 8, 13]
@@ -77,7 +77,7 @@ class EventManager:
                 json.dumps(EventManager.serialize(event)),
                 retry
             )
-            self.queue.append(0, item)
+            self.queue.append(item)
             if self._is_queue_full():
                 self.queue = self.queue[:len(self.queue - 1)]
         return res
@@ -136,7 +136,7 @@ class EventManager:
     def serialize(obj):
         return {
             "rid": obj.rid,
-            "eventType": obj.event_type.value,
+            "eventType": obj.event_type,
             "userId": obj.user_id,
             "userTraits": {
                 "name": obj.user_traits.name,
